Module validation

Module validation 

Traits

Validate
This is the original trait that was implemented by deriving Validate. It will still be implemented for struct validations that don’t take custom arguments. The call is being forwarded to the ValidateArgs<'v_a> trait.

Functions

alphabetic
alphanumeric
ascii_alphanumeric
assert_false
assert_true
errors_to_details
lowercase
no_whitespace
non_empty_map
non_empty_vec
non_negative_f64
non_negative_i32
non_negative_i64
not_blank
not_empty
numeric_text
percentage
positive_f64
positive_i32
positive_i64
required
uppercase

Derive Macros

Validate